/* See LICENSE file for copyright and license details. */

#include <X11/XF86keysym.h>

/* appearance */
static const unsigned int borderpx  = 2;        /* border pixel of windows */
static const unsigned int snap      = 32;       /* snap pixel */
static const unsigned int systraypinning = 0;   /* 0: sloppy systray follows selected monitor, >0: pin systray to monitor X */
static const unsigned int systrayonleft = 0;    /* 0: systray in the right corner, >0: systray on left of status text */
static const unsigned int systrayspacing = 2;   /* systray spacing */
static const int systraypinningfailfirst = 1;   /* 1: if pinning fails, display systray on the first monitor, False: display systray on the last monitor*/
static const int showsystray        = 1;        /* 0 means no systray */
static const int showbar            = 1;        /* 0 means no bar */
static const int topbar             = 1;        /* 0 means bottom bar */
static const char *fonts[]          = { "monospace:size=10" };
static const char dmenufont[]       = "monospace:size=10";

static const char col_bg_inactive[]  = "#444444";
static const char col_fg_inactive[]  = "#bbbbbb";

static const char col_bg_highlight[] = "#ffaaaa";
static const char col_fg_highlight[] = "#000000";

static const char *colors[][3]      = {
    /*               fg         bg         border   */
    [SchemeNorm] = { col_fg_inactive,  col_bg_inactive,  col_bg_inactive },
    [SchemeSel]  = { col_fg_highlight, col_bg_highlight, col_bg_highlight }
};

/* tagging */
static const char *tags[] = { "main", "term", "www", "chat", "5", "6", "7", "8", "9", };

static const Rule rules[] = {
    /* class          instance    title       tags mask    isfloating   monitor */
    { "Gimp",         NULL,       NULL,       0,           True,        -1 },
    { "firefox",      NULL,       NULL,       1 << 2,      False,       -1 },
    { "discord",      NULL,       NULL,       1 << 3,      False,       -1 },
    { "Thunderbird",  NULL,       NULL,       2,           False,       -1 },
    { "stalonetray",  NULL,       NULL,       1,           False,       -1 },
    { "chrome",       NULL,       NULL,       4,           False,       -1 },
};

/* layout(s) */
static const float mfact      = 0.55; /* factor of master area size [0.05..0.95] */
static const Bool resizehints = True; /* True means respect size hints in tiled resizals */
static const int nmaster     = 1;    /* number of clients in master area */
static const int lockfullscreen = 1; /* 1 will force focus on the fullscreen window */

static const Layout layouts[] = {
    /* symbol     arrange function */
    { "[]=",      tile },    /* first entry is default */
    { "><>",      NULL },    /* no layout function means floating behavior */
    { "[M]",      monocle },
};

/* key definitions */
#define MODKEY Mod4Mask
#define TAGKEYS(KEY,TAG) \
    { MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
    { MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
    { MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
    { MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* commands */

// dmenu
static char dmenumon[2] = "0"; /* component of dmenucmd, manipulated in spawn() */
static const char *dmenucmd[] = { 
    "dmenu_run", 
    "-m", dmenumon, 
    "-fn", dmenufont, 
    "-nb", col_bg_inactive, 
    "-nf", col_fg_inactive, 
    "-sb", col_bg_highlight, 
    "-sf", col_fg_highlight, NULL };

// terminal
static const char *termcmd[]  = { "alacritty", NULL };

// general & sys
static const char *locksaver[] = { "i3lock", "-c", "#000000", NULL };
static const char *vol_up[] = { "amixer", "set", "Master", "5%+", NULL };
static const char *vol_down[] = { "amixer", "set", "Master", "5%-", NULL };
static const char *vol_mute[] = { "amixer", "set", "Master", "toggle", NULL };
static const char *light_up[] = {"light", "-A", "5", NULL};
static const char *light_down[] = {"light", "-U", "5", NULL};

// screenshots
static const char *screenshot[] = {"flameshot", "full", "-c", NULL};
static const char *screenshot_partial[] = {"flameshot", "gui", "-c", NULL};

// kill dwm
static const char *dwmdie[] = {"/bin/sh", "-c", "pkill dwm-start && pkill dwm", "null"};

static Key keys[] = {
    /* modifier                     key        function        argument */
    { MODKEY,                       XK_Return, spawn,          {.v = termcmd } },
    { MODKEY|ShiftMask,             XK_d,      spawn,          {.v = dmenucmd } },
    { MODKEY|ShiftMask,             XK_e,      spawn,          {.v = dwmdie } },
    { MODKEY,                       XK_l,      spawn,          {.v = locksaver } },
    { MODKEY,                       XK_b,      togglebar,      {0} },
    { MODKEY,                       XK_j,      focusstack,     {.i = +1 } },
    { MODKEY,                       XK_k,      focusstack,     {.i = -1 } },
    { MODKEY|Mod1Mask,              XK_h,      incnmaster,     {.i = +1} },
    { MODKEY|Mod1Mask,              XK_u,      incnmaster,     {.i = -1} },
    { MODKEY|ShiftMask,             XK_Return, zoom,           {0} },
    { MODKEY,                       XK_Tab,    view,           {0} }, 
    { MODKEY|ShiftMask,             XK_c,      killclient,     {0} },
    { MODKEY,                       XK_t,      setlayout,      {.v = &layouts[0]} },
    { MODKEY,                       XK_f,      setlayout,      {.v = &layouts[1]} },
    { MODKEY,                       XK_m,      setlayout,      {.v = &layouts[2]} },
    { MODKEY,                       XK_space,  setlayout,      {0} },
    { MODKEY|ShiftMask,             XK_space,  togglefloating, {0} },
    { MODKEY,                       XK_0,      view,           {.ui = ~0 } },
    { MODKEY|ShiftMask,             XK_0,      tag,            {.ui = ~0 } },
    { MODKEY,                       XK_comma,  focusmon,       {.i = -1 } },
    { MODKEY,                       XK_period, focusmon,       {.i = +1 } },
    { MODKEY|ShiftMask,             XK_comma,  tagmon,         {.i = -1 } },
    { MODKEY|ShiftMask,             XK_period, tagmon,         {.i = +1 } },
    { 0,                            XK_Print,  spawn,          {.v = screenshot } },
    { Mod1Mask,                    XK_Print,  spawn,          {.v = screenshot_partial } },
    { 0,             XF86XK_AudioRaiseVolume,  spawn,          {.v = vol_up   } },
    { 0,             XF86XK_AudioLowerVolume,  spawn,          {.v = vol_down } },
    { 0,             XF86XK_AudioMute,         spawn,          {.v = vol_mute } },
    { 0,             XF86XK_MonBrightnessUp,   spawn,          {.v = light_up} },
    { 0,             XF86XK_MonBrightnessDown, spawn,          {.v = light_down} },
    TAGKEYS(                        XK_1,                      0)
    TAGKEYS(                        XK_2,                      1)
    TAGKEYS(                        XK_3,                      2)
    TAGKEYS(                        XK_4,                      3)
    TAGKEYS(                        XK_5,                      4)
    TAGKEYS(                        XK_6,                      5)
    TAGKEYS(                        XK_7,                      6)
    TAGKEYS(                        XK_8,                      7)
    TAGKEYS(                        XK_9,                      8)
    { MODKEY|ShiftMask|Mod1Mask,    XK_q,      quit,           {0} },
};

/* button definitions */
/* click can be ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static Button buttons[] = {
    /* click                event mask      button          function        argument */
    { ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
    { ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
    { ClkWinTitle,          0,              Button2,        zoom,           {0} },
    { ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
    { ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
    { ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
    { ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
    { ClkTagBar,            0,              Button1,        view,           {0} },
    { ClkTagBar,            0,              Button3,        toggleview,     {0} },
    { ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
    { ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};

